@@ -2,32 +2,36 @@ package File::Copy::Link;
 
 use strict;
 use warnings;
- 
+
 use Carp;
 use File::Copy ();
 
 require Exporter;
-use base qw(Exporter);
+push our @ISA, qw(Exporter);
 
 our @EXPORT_OK = qw(copylink safecopylink);
-our $VERSION = '0.04';
+our $VERSION   = '0.200';
 
 sub copylink {
-    local $_ = @_ ? shift : $_;                 # default to $_ 
+    local $_ = @_ ? shift : $_;    # default to $_
     croak "$_ not a link\n" unless -l;
-    open my $fh, '<', $_ or croak "Can't open link $_: $!\n"; 
+    open my $fh, '<', $_ or croak "Can't open link $_: $!\n";
     unlink or croak "Can't unlink link $_: $!\n";
-    return File::Copy::copy $fh, $_ or croak "copy($fh $_) failed: $!\n";
+    my $ok = File::Copy::copy $fh, $_;
+    croak "copy($fh $_) failed: $!\n" unless $ok;
+    return $ok;
 }
 
 sub safecopylink {
-    local $_ = @_ ? shift : $_;                 # default to $_ 
+    local $_ = @_ ? shift : $_;    # default to $_
     croak "$_ not a link\n" unless -l;
     require File::Spec::Link;
     my $orig = File::Spec::Link->linked($_);
     croak "$_ link problem\n" unless defined $orig;
     unlink or croak "Can't unlink link $_: $!\n";
-    return File::Copy::copy $orig, $_ or croak "copy($orig $_) failed: $!\n";
+    my $ok = File::Copy::copy $orig, $_;
+    croak "copy($orig $_) failed: $!\n" unless $ok;
+    return $ok;
 }
 
 1;
@@ -36,8 +40,7 @@ __END__
 
 =head1 NAME
 
-File::Copy::Link -
-Perl extension for replacing a link by a copy of the linked file.
+File::Copy::Link - extension for replacing a link by a copy of the linked file
 
 =head1 SYNOPSIS
 
@@ -80,15 +83,15 @@ copylink(1) File::Copy(3) File::Spec::Link(3)
 
 =head1 AUTHOR
 
-Robin Barker, E<lt>Robin.Barker@npl.co.ukE<gt>
+Robin Barker, <RMBarker@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003, 2006, 2007 by Robin Barker
+Copyright 2003, 2006, 2007, 2011, 2014, 2024 by Robin Barker
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
 
 =cut
 
-$Id: Link.pm 175 2007-12-30 16:28:03Z rmb1 $
+$Id$
